@@ -34,11 +34,6 @@ using std::string;
 using std::string_view;
 using std::vector;
 
-DEFINE_bool(
-    fb303_service_data_skip_regex_match_cache,
-    false,
-    "If true, getRegexCounters() will not query the regex match cache.");
-
 namespace facebook::fb303 {
 
 template <typename T>
@@ -464,35 +459,13 @@ map<string, int64_t> ServiceData::getSelectedCounters(
 void ServiceData::getRegexCounters(
     map<string, int64_t>& _return,
     const string& regex) const {
-  if (!FLAGS_fb303_service_data_skip_regex_match_cache) {
-    getRegexCountersOptimized(_return, regex);
-    return;
-  }
-
-  const boost::regex regexObject(regex);
-  auto keys = getCounterKeys();
-  keys.erase(
-      std::remove_if(
-          keys.begin(),
-          keys.end(),
-          [&](const std::string& key) {
-            return !regex_match(key, regexObject);
-          }),
-      keys.end());
-
-  getSelectedCounters(_return, keys);
-}
-
-void ServiceData::getRegexCountersOptimized(
-    map<string, int64_t>& output,
-    const string& regex) const {
   const auto key = folly::RegexMatchCache::regex_key_and_view(regex);
   const auto now = folly::RegexMatchCache::clock::now();
   std::vector<std::string> keys;
   detail::cachedFindMatches(keys, counters_, key, now);
   quantileMap_.getRegexKeys(keys, key, now);
   dynamicCounters_.getRegexKeys(keys, key, now);
-  getSelectedCounters(output, keys);
+  getSelectedCounters(_return, keys);
 }
 
 map<string, int64_t> ServiceData::getRegexCounters(const string& regex) const {
@@ -501,17 +474,10 @@ map<string, int64_t> ServiceData::getRegexCounters(const string& regex) const {
   return _return;
 }
 
-map<string, int64_t> ServiceData::getRegexCountersOptimized(
-    const string& regex) const {
-  map<string, int64_t> output;
-  getRegexCountersOptimized(output, regex);
-  return output;
-}
-
 void ServiceData::trimRegexCache(const std::chrono::seconds maxstale) {
   const auto now = folly::RegexMatchCache::clock::now();
   const auto expiry = now - maxstale;
-  counters_.wlock()->matches.purge(expiry);
+  detail::cachedTrimStale(counters_, expiry);
   quantileMap_.trimRegexCache(expiry);
   dynamicCounters_.trimRegexCache(expiry);
 }
